{ config, pkgs, lib, ... }: {

  imports = [

    ../../system/desktop

    ./hardware-configuration.nix
    ./packages.nix
    ./syncthing.nix
    ./tinc.nix

    #./wifi-access-point.nix
    #./wireshark.nix
    ./scanner.nix

  ];

  #sops.defaultSopsFile = ../../secrets/sterni.yaml;
  networking.hostName = "sterni";

  system.custom.wifi.interfaces = [ "wlp3s0" ];

  security.wrappers = {
    pmount = {
      source = "${pkgs.pmount}/bin/pmount";
      setuid = true;
      owner = "root";
      group = "root";
    };
    pumount = {
      source = "${pkgs.pmount}/bin/pumount";
      setuid = true;
      owner = "root";
      group = "root";
    };
  };

  # keybase
  services.keybase.enable = false;
  services.kbfs.enable = false;

  programs.custom.steam.enable = true;
  programs.custom.video.enable = false;

  services.printing.enable = true;

  # fonts
  # -----
  programs.custom.urxvt.fontSize = 12;
  programs.custom.xterm.fontSize = 12;
  system.custom.fonts.dpi = 100;

  virtualisation = {
    docker.enable = false;

    virtualbox = {
      host.enable = false;
      guest.x11 = false;
      guest.enable = false;
    };
  };

  configuration.desktop = {
    width = 1366;
    height = 768;
  };

  services.xserver.desktopManager.gnome.enable = true;

  custom.samba-share = {
    enable = true;
    folders = {
      #public = "/home/palo/movies";
      share = "/home/share";
      video = "/home/video-material";
      #syncthing = "/mnt/syncthing";
      #movies = "/mnt/syncthing/movies";
      #series = "/mnt/syncthing/series";
    };
  };

  # enable this to use sidequest
  programs.adb.enable = true;
  users.users.mainUser.extraGroups = [ "adbusers" "video" ];

  # for congress and streaming
  hardware.opengl = {
    enable = true;
    extraPackages = [ pkgs.vaapiIntel ];
    driSupport = true;
    driSupport32Bit = true;
  };
  nixpkgs.config.packageOverrides = pkgs: {
    vaapiIntel = pkgs.vaapiIntel.override { enableHybridCodec = true; };
  };

}

